# leia


[![pypi version](https://img.shields.io/pypi/v/leia.svg)](https://pypi.python.org/pypi/leia)
[![Travis Status](https://img.shields.io/travis/cmeister2/leia.svg)](https://travis-ci.org/cmeister2/leia)
[![Documentation Status](https://readthedocs.org/projects/leia/badge/?version=latest)](https://leia.readthedocs.io/en/latest/?badge=latest)


leia is a layering and compositing library for Python and PIL images.


- Free software: MIT license
- Documentation: https://leia.readthedocs.io.


## Features
- TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [cmeister2/cookiecutter-pypackage](https://github.com/cmeister2/cookiecutter-pypackage) project template.
